summaryrefslogtreecommitdiffstats
path: root/testing
diff options
context:
space:
mode:
authorerg@chromium.org <erg@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-11-05 22:50:57 +0000
committererg@chromium.org <erg@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-11-05 22:50:57 +0000
commitae9fafd5dc78e603e6111774cb23fed69ce548b2 (patch)
tree61a9441a03208bcfd0563a39bcdfe50372c9b433 /testing
parent058b8e14eabc02468614badff2e7908e022fb244 (diff)
downloadchromium_src-ae9fafd5dc78e603e6111774cb23fed69ce548b2.zip
chromium_src-ae9fafd5dc78e603e6111774cb23fed69ce548b2.tar.gz
chromium_src-ae9fafd5dc78e603e6111774cb23fed69ce548b2.tar.bz2
Revert 233071 "Migrate to Openbox from IceWM (In chrome scripts)"
Looks like openbox wasn't installed on everything. > Migrate to Openbox from IceWM (In chrome scripts) > > BUG=125106 > R=maruel@chromium.org > > Review URL: https://codereview.chromium.org/55083004 BUG=125106, 308335 TBR=erg@chromium.org Review URL: https://codereview.chromium.org/60343005 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@233116 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'testing')
-rwxr-xr-xtesting/xvfb.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/testing/xvfb.py b/testing/xvfb.py
index 51c1ad3..6ac0056 100755
--- a/testing/xvfb.py
+++ b/testing/xvfb.py
@@ -82,7 +82,7 @@ def run_executable(cmd, build_dir, env):
"""Runs an executable within a xvfb buffer on linux or normally on other
platforms.
Requires that both xvfb and openbox are installed on linux.
Detects recursion with an environment variable and do not create a recursive X
buffer if present.
@@ -109,11 +109,11 @@ def run_executable(cmd, build_dir, env):
# Some ChromeOS tests need a window manager. Technically, it could be
# another script but that would be overkill.
try:
- wm_cmd = ['openbox']
+ ice_cmd = ['icewm']
subprocess.Popen(
- wm_cmd, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, env=env)
+ ice_cmd, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, env=env)
except OSError:
- print >> sys.stderr, 'Failed to run %s' % ' '.join(wm_cmd)
+ print >> sys.stderr, 'Failed to run %s' % ' '.join(ice_cmd)
return 1
return test_env.run_executable(cmd, env)
finally:
@@ -82,7 +82,7 @@ def run_executable(cmd, build_dir, env):
"""Runs an executable within a xvfb buffer on linux or normally on other
platforms.
- Requires that both xvfb and openbox are installed on linux.
+ Requires that both xvfb and icewm are installed on linux.
Detects recursion with an environment variable and do not create a recursive X
buffer if present.